!------------------------------------------------------------
!------------------------------------------------------------
!           Plant's Model of Bursting Nerve Cells
!------------------------------------------------------------
!------------------------------------------------------------

      SUBROUTINE FUNC(NDIM,U,ICP,PAR,IJAC,F,DFDU,DFDP) 
!     ---------- ---- 

      IMPLICIT NONE
      INTEGER, INTENT(IN) :: NDIM, ICP(*), IJAC
      DOUBLE PRECISION, INTENT(IN) :: U(NDIM), PAR(*)
      DOUBLE PRECISION, INTENT(OUT) :: F(NDIM)
      DOUBLE PRECISION, INTENT(INOUT) :: DFDU(NDIM,NDIM), DFDP(NDIM,*)

      DOUBLE PRECISION VI, VK, VL, VCa, gK, gL, Kp, Kc, rho, txT, zeta, gi, gP, gT
      DOUBLE PRECISION V, xT, xK, yI, c, a, b, Vs, am, ah, an, bm, bh, bn, si, sK
      DOUBLE PRECISION txK, tyI, zI, sT

       VI   = 30.d0
       VK   =-75.d0
       VL   =-40.d0
       VCa  = 140.d0
       gK   = 0.3d0
       gL   = 0.003d0
       Kp   = 0.5d0
       Kc   = 0.0085d0
       rho  = 0.0003d0
       txT  = 235.d0
       zeta = 1.d0

       gI = PAR(1)
       gP = PAR(2)
       gT = PAR(3)

       V  = U(1)
       xT = U(2)
       xK = U(3)
       yI = U(4)
       c  = U(5)

       a  = 127.d0/(VI-VK)
       b  = (115.d0*VK+12.d0*VI)/(VI-VK)
       Vs = a*V-b

       am = 0.1d0*(50.d0-Vs)/(DEXP((50.d0-Vs)/10.d0)-1.d0)
       ah = 0.07d0*DEXP((25.d0-Vs)/20.d0)
       an = 0.01d0*(55.d0-Vs)/(DEXP((55.d0-Vs)/10.d0)-1.d0)
       bm = 4.d0*DEXP((25.d0-Vs)/18.d0)
       bh = 1.d0/(DEXP((55.d0-Vs)/10.d0)+1.d0)
       bn = 0.125d0*DEXP((45.d0-Vs)/80.d0)

       sI  = am/(am+bm)
       sK  = an/(an+bn)
       txK = 12.5d0/(an+bn)
       tyI = 12.5d0/(ah+bh)
       zI  = ah/(ah+bh)
       sT  = 1.d0/(DEXP(0.15d0*(-50.d0-V))+1.d0)

       F(1) = (gI*sI**3*yI + gT*xT) * (VI-V)                            &
            + (gK*xK**4 + gP*c/(Kp+c)) * (VK-V)                         &
            + gL * (VL-V)
       F(2) = (sT-xT) / (txT*zeta)
       F(3) = (sK-xK) / (txK*zeta)
       F(4) = (zI-yI) / (tyI*zeta)
       F(5) = rho * (Kc*xT*(VCa-V) - c)

      END SUBROUTINE FUNC

      SUBROUTINE STPNT(NDIM,U,PAR,T)
!     ---------- ----- 

      IMPLICIT NONE
      INTEGER, INTENT(IN) :: NDIM
      DOUBLE PRECISION, INTENT(INOUT) :: U(NDIM),PAR(*)
      DOUBLE PRECISION, INTENT(IN) :: T

      DOUBLE PRECISION gI,gP,gT

       gI = 50.d0
       gP = 0.03d0
       gT = 0.01d0

       PAR(1) = gI
       PAR(2) = gP
       PAR(3) = gT

       U(1) =-2.329601d0
       U(2) = 9.992162d-1
       U(3) = 7.373314d-1
       U(4) = 6.135948d-3
       U(5) = 1.208853d0

      END SUBROUTINE STPNT

      SUBROUTINE BCND 
      END SUBROUTINE BCND

      SUBROUTINE ICND 
      END SUBROUTINE ICND

      SUBROUTINE FOPT 
      END SUBROUTINE FOPT

      SUBROUTINE PVLS 
      END SUBROUTINE PVLS
